@@ -2,10 +2,12 @@ from .code import Code
 from .payment import Payment
 from .account import Account
 from .preauth import Preauth
+from .pending import Pending
 
 __all__ = [
         'Code',
         'Payment',
         'Account',
         'Preauth',
+        'Pending',
 ]
